@@ -341,7 +341,7 @@ function check_configurable_variables($con, $table, $items_json_array){
 				break;
 			case "fqdn":
 			case "string":
-				$qadd = "ALTER TABLE $table ADD $col varchar(128) NOT NULL default '$default'";
+				$qadd = "ALTER TABLE $table ADD $col varchar(255) NOT NULL default '$default'";
 				$radd = mysqli_query($con, $qadd)or die("Cannot execute query: \"$qadd\" line ".__LINE__." in file ".__FILE__.", mysql said: ".mysqli_error($con));
 				break;
 			default:
@@ -377,8 +377,8 @@ function check_configurable_variables($con, $table, $items_json_array){
 				break;
 			case "fqdn":
 			case "string":
-				if($a_type != "varchar(128)" || $a_def != $default){
-					$qadd = "ALTER TABLE $table CHANGE $col $col varchar(128) NOT NULL default '$default'";
+				if($a_type != "varchar(255)" || $a_def != $default){
+					$qadd = "ALTER TABLE $table CHANGE $col $col varchar(255) NOT NULL default '$default'";
 					$radd = mysqli_query($con, $qadd)or die("Cannot execute query: \"$qadd\" line ".__LINE__." in file ".__FILE__.", mysql said: ".mysqli_error($con));
 				}
 				break;
@@ -400,6 +400,10 @@ check_configurable_variables($con, "clusters", $dec_json["clusters"]);
 ### After all the db schema is in, perform the default INSERTs
 $q = array();
 
+# This fixes old dbs
+$q[] = "ALTER TABLE ips DROP KEY uniquemachine;";
+$q[] = "ALTER TABLE ips ADD CONSTRAINT uniquemachine UNIQUE (`network`,`machine`,`usefor`,`vip_usage`);";
+
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (1,'compute');";
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (2,'controller');";
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (3,'network');";
@@ -416,6 +420,7 @@ $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (13,'debmirror');";
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (14,'tempest');";
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (15,'billosd');";
 $q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (16,'billmon');";
+$q[] = "INSERT IGNORE INTO `roles` (`id`, `name`) VALUES (17,'dns');";
 
 foreach ($q as $sql){
 	$r = mysqli_query($con, $sql);
