@@ -382,8 +382,12 @@ function hardware_profile_remove_hdd_in_slot($physdrives, $slot_num){
     return $physdrives;
 }
 
-function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_name){
-    $debug_megacli_apply = "no";
+function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_name, $debug="no"){
+    if($debug == "yes"){
+        $debug_megacli_apply = "yes";
+    }else{
+        $debug_megacli_apply = "no";
+    }
     $json["status"] = "success";
     $json["message"] = "Successfuly queried API.";
 
@@ -448,7 +452,7 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
     if($ret["status"] != "success"){
         return $ret;
     }
-    if($ret["data"] == "yes"){
+    if($ret["data"] == "yes" && $debug_megacli_apply == "no"){
         $json["data"] = "Already applied.";
         return $json;
     }
@@ -456,7 +460,7 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
     # Clear all foreign RAID
     $cmd = "megacli -CfgForeign -Clear -a0";
     if($debug_megacli_apply == "yes"){
-        print($cmd."\n");
+        $json["data"][] = $cmd;
     }else{
         $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
     }
@@ -464,7 +468,7 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
     # Delete any existing virtual disk
     $cmd = "megacli -CfgLdDel -LALL -a0";
     if($debug_megacli_apply == "yes"){
-        print($cmd."\n");
+        $json["data"][] = $cmd;
     }else{
         $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
     }
@@ -474,7 +478,7 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
         $slot = $hdd["slot"];
         $cmd = "megacli -PDMakeGood -PhysDrv[$enclosure_number:$slot] -force -a0";
         if($debug_megacli_apply == "yes"){
-            print($cmd."\n");
+            $json["data"][] = $cmd;
         }else{
             $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
         }
@@ -506,6 +510,22 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
         }
 //        print_r($machine_physbd_tmp);
         switch($raid_type){
+        case "JBOD":
+            $megacli_cfg = "megacli -PDMakeJBOD -PhysDrv [";
+            $cnt = 0;
+            foreach($hdd_slots as &$one_slot){
+                if($cnt != 0){
+                    $megacli_cfg .= ",";
+                }
+                $megacli_cfg .= "$enclosure_number:$one_slot";
+                $machine_physbd_tmp = hardware_profile_remove_hdd_in_slot($machine_physbd_tmp, $one_slot);
+                $cnt+=1;
+                if($cnt >= $layout["num_max"]){
+                    break;
+                }
+            }
+            $megacli_cfg .= "] -a0";
+            break;
         case "0":
             $megacli_cfg = "megacli -CfgLdAdd -r0 [";
             $cnt = 0;
@@ -533,6 +553,9 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
                 $megacli_cfg .= "$enclosure_number:$one_slot";
                 $machine_physbd_tmp = hardware_profile_remove_hdd_in_slot($machine_physbd_tmp, $one_slot);
                 $cnt+=1;
+                if($cnt >= $layout["num_max"]){
+                    break;
+                }
             }
             $megacli_cfg .= "] $options -a0";
             break;
@@ -560,21 +583,16 @@ function hardware_profile_apply_megacli_raid($con, $conf, $machine_id, $profile_
             return $json;
             break;
         }
-//        echo "$megacli_cfg\n";
         if($debug_megacli_apply == "yes"){
-            print($megacli_cfg."\n");
+            $json["data"][] = $megacli_cfg;
         }else{
             $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $megacli_cfg);
         }
     }
-//    if($debug_megacli_apply == "yes"){
-//        print("openstack-cluster-installer-agent\n");
-//    }else{
-//        $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], "openstack-cluster-installer-agent");
-//    }
 
-
-    $json["data"]="Applied";
+    if($debug_megacli_apply == "no"){
+        $json["data"]="Applied";
+    }
     return $json;
 }
 
@@ -605,6 +623,14 @@ function hardware_profile_apply_megacli_reset_raid($con, $conf, $machine_id){
         $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
     }
 
+    # Do a CfgClr
+    $cmd = "megacli -CfgClr -Force -aALL";
+    if($debug_megacli_apply == "yes"){
+        print($cmd."\n");
+    }else{
+        $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
+    }
+
     # Get the enclosure number
     $cmd = "megacli -EncInfo -aALL -NoLog | grep 'Device ID' | cut -d: -f2 | cut -d' ' -f2";
     $ret = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
