@@ -19,6 +19,15 @@ function perform_ipmitool_cmd($con, $conf, $machine_id, $ipmi_username, $ipmi_pa
     }
     $machine = mysqli_fetch_array($r);
 
+    # Call oci-lenovo-set-default-onecli-config. It will itself know if
+    # it runs on a Lenovo machine and if /usr/bin/onecli is present, and
+    # skip running if conditions aren't met.
+    # Note that it is mandatory to run it, otherwise setting-up the IPMI
+    # password will not work.
+    $cmd = "/usr/bin/oci-lenovo-set-default-onecli-config";
+    $json["message"] .= "\n$cmd";
+    send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
+
     # This is for HP cloud line
     if($machine["product_name"] == "CL2600 Gen10" || $machine["product_name"] == "CL2800 Gen10"){
         // What's below is proven to work with HP Cloud Line CL2600 and CL2800 machines
@@ -278,6 +287,26 @@ function perform_ipmitool_cmd($con, $conf, $machine_id, $ipmi_username, $ipmi_pa
     $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
     $json["message"] .= "\n$out";
 
+    if($machine["ipmi_addr"] != $ipmi_addr && ($machine["product_name"] == "ProLiant DL385 Gen10" || $machine["product_name"] == "ProLiant DL385 Gen10 Plus")){
+        # Enable the IPMI over LAN, which is off by default on these machines
+        $cmd = "echo '<RIBCL VERSION=\\\"2.0\\\"><LOGIN USER_LOGIN=\\\"admin\\\" PASSWORD=\\\"password\\\"><RIB_INFO mode=\\\"write\\\"><MOD_GLOBAL_SETTINGS><IPMI_DCMI_OVER_LAN_ENABLED VALUE=\\\"Y\\\"/></MOD_GLOBAL_SETTINGS></RIB_INFO></LOGIN></RIBCL>' >set-ipmi-on.xml ; hponcfg -f set-ipmi-on.xml ; rm set-ipmi-on.xml";
+        $json["message"] .= "\n$cmd";
+        $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
+        $json["message"] .= "\n$out";
+
+        # Add the ILO license if we have the /root/License.xml file (should be present in the Live OS only)
+        $cmd = "if [ -e /root/License.xml ] ; then hponcfg -f /root/License.xml ; fi";
+        $json["message"] .= "\n$cmd";
+        $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
+        $json["message"] .= "\n$out";
+
+        // Since we changed IP address, the ILO needs a reset (thank you HP !)
+        $cmd = "ipmitool mc reset";
+        $json["message"] .= "\n$cmd";
+        $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
+        $json["message"] .= "\n$out";
+    }
+
     return $json;
 }
 
@@ -476,10 +505,17 @@ function automatic_ipmi_assign($con, $conf, $machine_id){
                 if($ret["status"] == "success"){
                     $ipmi_addr = $ret["data"];
                     if($do_update == "yes"){
-                        $hex = base64_encode(openssl_random_pseudo_bytes(9, $crypto_strong));
+                        if($machine["product_name"] == "Lenovo" || $machine["product_name"] == "LENOVO"){
+                            # This produces a 16 char long pass
+                            $num_bytes = 12;
+                        }else{
+                            # This produces a 12 char long pass
+                            $num_bytes = 9;
+                        }
+                        $hex = base64_encode(openssl_random_pseudo_bytes($num_bytes, $crypto_strong));
+                        $json = perform_ipmitool_cmd($con, $conf, $machine_id, $conf["ipmi"]["automatic_ipmi_username"], $hex, $ipmi_addr, $ipmi_net_def_gateway, $ipmi_netmask);
                         $qmachine = "UPDATE machines SET ipmi_use='yes', ipmi_call_chassis_bootdev='yes', ipmi_addr='$ipmi_addr', ipmi_netmask='$ipmi_netmask', ipmi_default_gw='$ipmi_net_def_gateway', ipmi_vlan='$net_vlan', ipmi_username='". $conf["ipmi"]["automatic_ipmi_username"] ."', ipmi_password='$hex' WHERE id='$machine_id'";
                         mysqli_query($con, $qmachine);
-                        $json = perform_ipmitool_cmd($con, $conf, $machine_id, $conf["ipmi"]["automatic_ipmi_username"], $hex, $ipmi_addr, $ipmi_net_def_gateway, $ipmi_netmask);
                     }
 # This looks wrong: we should never get int his case.
 #                }else{
