@@ -72,10 +72,25 @@ if($n == 0){
             }
             // Since the machine is booted and installed, we need to sign the puppet cert.
             // We can do it with sudo, as there's a sudoers file installed.
+            $cmd = "ls /usr/bin/puppetserver";
+            $output = array();
+            $return_var = 0;
+            exec($cmd, $output, $return_var);
+            if($return_var == 0){
+                $puppet_master_is_7_or_more = "yes";
+            }else{
+                $puppet_master_is_7_or_more = "no";
+            }
+
             $output = "";
             $machine_hostname = $machine["hostname"];
-            error_log("install-status.php: sudo /usr/bin/puppet cert sign $machine_hostname");
-            $cmd = "sudo /usr/bin/puppet cert sign " . $machine_hostname;
+            if($puppet_master_is_7_or_more == "yes"){
+                $mycmd = "puppetserver cert sign --certname";
+            }else{
+                $mycmd = "puppet cert sign";
+            }
+            error_log("install-status.php: sudo /usr/bin/$mycmd $machine_hostname");
+            $cmd = "sudo /usr/bin/$mycmd " . $machine_hostname;
             exec($cmd , $output);
 
             // As the machine is installed, we can setup its root password.
