@@ -57,6 +57,17 @@ if (!isset($data["machine"][0]["productname"])){
     }
 }
 
+if (!isset($data["machine"][0]["system_manufacturer"])){
+    $system_manufacturer = "Unknown";
+}else{
+    $reg = '/^[ ;_.0-9a-zA-Z-(),+]{1,120}$/';
+    if(!preg_match($reg, $data["machine"][0]["system_manufacturer"])){
+        $system_manufacturer = "Invalid.";
+    }else{
+        $system_manufacturer = $data["machine"][0]["system_manufacturer"];
+    }
+}
+
 if (!isset($data["machine"][0]["ladvd_report"])){
     $ladvd_report = "No ladvd report";
 }else{
@@ -203,7 +214,7 @@ if (!isset($data["machine"][0]["secure_boot"]) || $data["machine"][0]["secure_bo
 $r = mysqli_query($con, "SELECT * FROM machines WHERE serial='" . $safe_serial_number . "'");
 $n = mysqli_num_rows($r);
 if($n == 0){
-    $r = mysqli_query($con, "INSERT INTO machines (ipaddr, dhcp_ip, serial, product_name, ladvd_report, bios_version, dell_lifecycle_version, ipmi_firmware_version, ipmi_detected_ip, memory, use_oci_sort_dev, cpu_vendor, cpu_model_name, cpu_mhz, cpu_threads, cpu_core_per_socket, cpu_sockets, boot_uefi, secure_boot, status) VALUES ('" . $remote_addr. "', '" . $remote_addr. "', '$safe_serial_number' , '$prod_name', '$ladvd_report', '$bios_version', '$dell_lifecycle_version', '$ipmi_version', '$ipmi_detected_ip', '$safe_memory_size', '$use_oci_sort_dev', '$cpu_vendor', '$cpu_model_name', '$cpu_mhz', '$cpu_threads', '$cpu_core_per_socket', '$cpu_sockets', '$boot_uefi', '$secure_boot', 'live')");
+    $r = mysqli_query($con, "INSERT INTO machines (ipaddr, dhcp_ip, serial, system_manufacturer, product_name, ladvd_report, bios_version, dell_lifecycle_version, ipmi_firmware_version, ipmi_detected_ip, memory, use_oci_sort_dev, cpu_vendor, cpu_model_name, cpu_mhz, cpu_threads, cpu_core_per_socket, cpu_sockets, boot_uefi, secure_boot, status) VALUES ('" . $remote_addr. "', '" . $remote_addr. "', '$safe_serial_number' ,'$system_manufacturer' ,'$prod_name', '$ladvd_report', '$bios_version', '$dell_lifecycle_version', '$ipmi_version', '$ipmi_detected_ip', '$safe_memory_size', '$use_oci_sort_dev', '$cpu_vendor', '$cpu_model_name', '$cpu_mhz', '$cpu_threads', '$cpu_core_per_socket', '$cpu_sockets', '$boot_uefi', '$secure_boot', 'live')");
     if($r === FALSE){
         $error = mysqli_error($con);
         printf("Error inserting: %s\n",  mysqli_error($con));
@@ -344,7 +355,7 @@ if($n == 0){
     $report_counter = $a["report_counter"] + 1;
 
     // We keep the machine id...
-    $req = "UPDATE machines SET report_counter='$report_counter', ipaddr='$remote_addr', memory='".$safe_memory_size."', serial='$safe_serial_number', product_name='$prod_name', ladvd_report='$ladvd_report', bios_version='$bios_version', dell_lifecycle_version='$dell_lifecycle_version', ipmi_firmware_version='$ipmi_version', ipmi_detected_ip='$ipmi_detected_ip', use_oci_sort_dev='$use_oci_sort_dev', cpu_vendor='$cpu_vendor', cpu_model_name='$cpu_model_name', cpu_mhz='$cpu_mhz', cpu_threads='$cpu_threads', cpu_core_per_socket='$cpu_core_per_socket', cpu_sockets='$cpu_sockets', boot_uefi='$boot_uefi', secure_boot='$secure_boot', lastseen=NOW() $dhcp_update WHERE serial='$safe_serial_number'";
+    $req = "UPDATE machines SET report_counter='$report_counter', ipaddr='$remote_addr', memory='".$safe_memory_size."', serial='$safe_serial_number', system_manufacturer='$system_manufacturer', product_name='$prod_name', ladvd_report='$ladvd_report', bios_version='$bios_version', dell_lifecycle_version='$dell_lifecycle_version', ipmi_firmware_version='$ipmi_version', ipmi_detected_ip='$ipmi_detected_ip', use_oci_sort_dev='$use_oci_sort_dev', cpu_vendor='$cpu_vendor', cpu_model_name='$cpu_model_name', cpu_mhz='$cpu_mhz', cpu_threads='$cpu_threads', cpu_core_per_socket='$cpu_core_per_socket', cpu_sockets='$cpu_sockets', boot_uefi='$boot_uefi', secure_boot='$secure_boot', lastseen=NOW() $dhcp_update WHERE serial='$safe_serial_number'";
     $r = mysqli_query($con, $req);
     if (isset($data["blockdevices"])){
         $blkdev_array = array();
